summaryrefslogtreecommitdiffstats
path: root/scripts/flash.sh
diff options
context:
space:
mode:
authorwbx <wbx@3c298f89-4303-0410-b956-a3cf2f4a3e73>2005-12-25 01:04:46 +0000
committerwbx <wbx@3c298f89-4303-0410-b956-a3cf2f4a3e73>2005-12-25 01:04:46 +0000
commit13b933ce77dc7e70ddab2b5ee860f01023876edc (patch)
tree7077093601302c971a984f863cece2d39df48bae /scripts/flash.sh
parent6535064031e51f8bef584e7c6b6431c2efbe4566 (diff)
add toshiba tftp commands
git-svn-id: svn://svn.openwrt.org/openwrt/trunk/openwrt@2766 3c298f89-4303-0410-b956-a3cf2f4a3e73
Diffstat (limited to 'scripts/flash.sh')
-rw-r--r--scripts/flash.sh24
1 files changed, 19 insertions, 5 deletions
diff --git a/scripts/flash.sh b/scripts/flash.sh
index e71108690..8841c3568 100644
--- a/scripts/flash.sh
+++ b/scripts/flash.sh
@@ -1,9 +1,9 @@
#!/bin/bash
-
-# flash script for linksys and asus routers
+#
+# tftp flash script for wireless routers
#
# Copyright (C) 2004 by Oleg I. Vdovikin <oleg@cs.msu.su>
-# Copyright (C) 2005 by Waldemar Brodkorb <wbx@dass-it.de>
+# Copyright (C) 2005 by Waldemar Brodkorb <wbx@openwrt.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -24,11 +24,11 @@ if [ -z "$1" ] || [ ! -f $1 ] || [ -z $2 ]; then
echo Usage: $0 firmware vendor
cat << EOF
IMPORTANT:
-Notes for Linksys router:
+Notes for Linksys / Asus WL500gx router:
be sure you have set boot_wait to yes. Power on your router
after executing this script.
-Notes for Asus router:
+Notes for Asus WL500g router:
be sure POWER led is flashing (If this is not the case
poweroff the device, push the reset button & power on
it again, then release button)
@@ -36,6 +36,16 @@ Notes for Asus router:
1) connect your pc to the LAN port
2) be sure your link is up and has an address in the
192.168.1.0/24 address range (and not the 192.168.1.1)
+
+Notes for Toshiba router:
+ boot_wait is enabled by default on these units.
+
+1) connect your pc to any of the four LAN ports
+2) be sure your link is up and has an address in the
+ 192.168.10.1/24 address range (and not the 192.168.10.1)
+3) run this script (unit will only accept .trx images)
+4) Turn unit power on.
+
EOF
exit 0
fi
@@ -49,4 +59,8 @@ elif [ "$2" == "linksys" ]; then
echo Flashing 192.168.1.1 using $1...
echo -en "rexmt 1\ntrace\nbinary\nput $1\nquit\n" | tftp 192.168.1.1
echo Please wait until power led stops flashing. Do not poweroff! Then you can login via telnet 192.168.1.1.
+elif [ "$2" == "toshiba" ]; then
+echo Flashing 192.168.10.1 using $1...
+echo -en "rexmt 1\ntrace\nbinary\nput $1\nquit\n" | tftp 192.168.10.1
+echo Unit will automatically reboot within 5 minutes. Do not power off. Then you can login via telnet 192.168.10.1.
fi